@@ -596,7 +596,7 @@ def number_converter(str_num: str) -> int:
         return [False]
 
 class TimeKeeper():
-    def __init__(self, supress:str) -> datetime:
+    def __init__(self, supress:str) -> None:
         '''
         pass y flag to supresses printing by this class so that user can print as per his needs
         '''
@@ -605,8 +605,6 @@ class TimeKeeper():
         self.logs = []
         self.logs.append(self.start_time)
         self.supress = supress
-
-        return self.start_time
     
     def log(self) -> datetime:
         '''
